@@ -23,26 +23,29 @@
  *		interprets it.				*
  * Returns:	retval (if quit program or no)		*
 \********************************************************/
-long maxlines;						/*extern val for lines*/
-long currentLine;					/*extern val for lines*/
-long LastLoc;                                           /*last cursor location*/
+off_t maxlines;						/*extern val for lines*/
+off_t currentLine;					/*extern val for lines*/
+off_t LastLoc;                                          /*last cursor location*/
 bool editHex;						/* flag to edit h or a*/
 int SIZE_CH;                                            /* global winch flag  */
 
-int wacceptch(WINS *win, long len, char *fpINfilename, char *fpOUTfilename)
+int wacceptch(WINS *win, off_t len)
 {
-    int  row = 0, col = 0, count,  val, tmpval, 	/* counters, etc.     */
+    intmax_t tmp_max;
+    
+    off_t count;
+    int  col = 0, val, tmpval, 	    			/* counters, etc.     */   
          ch[17],					/* holds search string*/
 	 eol = (BASE * 3) - 1,				/* end of line pos    */
-         save = 0,					/* to save on exit    */
 	 lastRow = 0, lastCol = 0,			/* last row/col coords*/
-	 prevVal, curVal,				/* vals @ cursor locs */
-	 tmp;
+	 curVal = 0,	        			/* vals @ cursor locs */
+	 tmp = 0;
 
-    long cl,						/* current loc in file*/
-	 gotoLoc = 0,					/* goto location      */
-	 lastLine = 0,					/* line b4 LastLine   */
-	 currentLine = 0;				/* current line value */
+    off_t cl,						/* current loc in file*/
+	  gotoLoc = 0,					/* goto location      */
+	  lastLine = 0,					/* line b4 LastLine   */
+	  currentLine = 0,				/* current line value */
+	  row = 0;
 
     char *gotoLocStr,					/* convert to gotoLoc */
          *temp,
@@ -58,6 +61,8 @@ int wacceptch(WINS *win, long len, char *fpINfilename, char *fpOUTfilename)
     SIZE_CH	= FALSE;				/* set winch to false */
     Winds       = win->hex;				/* curr edit window   */
     maxlines    = maxLines(len);			/* lines in file      */
+    
+    bool shouldExit = false;
 
     /*createStack(stack);*/				/* init the stack     */
     stack = NULL;
@@ -65,18 +70,23 @@ int wacceptch(WINS *win, long len, char *fpINfilename, char *fpOUTfilename)
 
     if (fpIN)						/* if file opened then*/
     {							/* highlight 0,0 loc  */
-        prevVal = curVal = getLocVal(0);
+        curVal = getLocVal(0);
 	wattron(win->ascii, A_UNDERLINE);
-	mvwprintw(win->ascii, 0, 0, "%c", curVal); 
+	if (USE_EBCDIC)
+		mvwprintw(windows->ascii, 0, 0, "%c", EBCDIC[curVal]);/* print EBCDIC char */
+	else	/* print ASCII  char */
+		mvwprintw(windows->ascii, 0, 0, (isprint(curVal)) ? "%c":".", (char)curVal);
 	wmove(win->hex, 0, 0);
 	wattrset(win->ascii, A_NORMAL);
     	wnoutrefresh(win->ascii);
 	doupdate();
     }
-
+        
 							/* get keys til exit  */
-    while (!(save=quitProgram(isEmptyStack(stack),(key = wgetch(Winds)))))
+    while(!shouldExit)
+    //while (!(save=quitProgram(isEmptyStack(stack),(key = wgetch(Winds)))))
     {
+        key = wgetch(Winds);
 	lastRow = row;
 	lastCol = col;
 	getyx(Winds, row, col);				/* curent cursor loc  */
@@ -103,6 +113,34 @@ int wacceptch(WINS *win, long len, char *fpINfilename, char *fpOUTfilename)
 	
 
 	switch (key) {					/* check keypress     */
+    
+							/* if exit key...     */
+	case CTRL_AND('q'):
+	case CTRL_AND('x'):
+	case KEY_F(8):
+		if (isEmptyStack(stack))
+		{
+			/* No pending changes */
+			shouldExit = true;
+		}
+		else
+		{
+			short int str = questionWin("Do you want to save changes? (y/n/c)");
+			if (str == 'Y' || str == 'y')
+			{
+				if (savefile(win) == 0)
+					shouldExit = true;
+			}
+			else if (str == 'N' || str == 'n')
+			{
+				shouldExit = true;
+			}
+			else if (str == 'C' || str == 'c')
+			{
+				continue;
+			}
+		}
+		break;
 
 	case KEY_UP:					/* if UP...           */
 		if (currentLine > 0) 			/* move up...         */
@@ -160,7 +198,7 @@ int wacceptch(WINS *win, long len, char *fpINfilename, char *fpOUTfilename)
 							/* if not in ll...    */
 			if ((val = searchList(head, cl)) == -1)
 		  	{
-			    fseek(fpIN, cl, SEEK_SET);	/* get val from file  */
+			    fseeko(fpIN, cl, SEEK_SET);	/* get val from file  */
 			    val = fgetc(fpIN);
 			}
 
@@ -351,7 +389,7 @@ int wacceptch(WINS *win, long len, char *fpINfilename, char *fpOUTfilename)
 		     maxLines(maxLoc(fpIN)); count++)
 		    outline(fpIN, count);
 
-		mvwprintw(windows->cur_address, 0, 0, "00000000"); 
+		mvwprintw(windows->cur_address, 0, 0, "%0*d", MIN_ADDR_LENGTH, 0); 
 		wmove((editHex) ? win->hex : win->ascii, 0, 0);
     		wnoutrefresh(win->ascii);
     		wnoutrefresh(win->address);
@@ -384,25 +422,27 @@ int wacceptch(WINS *win, long len, char *fpINfilename, char *fpOUTfilename)
 	case KEY_F(3):					/* if F3 or ^o...     */
 
 
-		if (openfile(win, fpINfilename))	/* open file          */
+		if (openfile(win))			/* open file          */
 		{
 		    if (fpIN)
-			prevVal = curVal = getLocVal(0);
-
+                    {
+			MIN_ADDR_LENGTH = getMinimumAddressLength(maxLoc(fpIN));
+			curVal = getLocVal(0);
+                    }                
 	 	    return TRUE;			/* TRUE if worked     */
 		}
 		break;
 
 	case CTRL_AND('s'):				/* if F2 or ^s...     */
 	case KEY_F(2):					/* save the file      */
-		savefile(win, fpINfilename, fpOUTfilename);
+		savefile(win);
 		break;
 
 	case CTRL_AND('f'):
 	case KEY_F(5):
  		/* SeachStr stores the last searched string into the format *\
 	 	\* "(XXXXXXX...)" with 10 being the max chars shown         */
-                if (!strcmp(fpINfilename, "")) 
+                if (!fpINfilename || !strcmp(fpINfilename, "")) 
 		{	 				/* output prompt      */
 		    wmove(win->hex_outline, LINES-1, 1);
                     wclrtoeol(win->hex_outline);
@@ -522,12 +562,12 @@ int wacceptch(WINS *win, long len, char *fpINfilename, char *fpOUTfilename)
 		/* check to see if screen is filled     */
 		if ((maxlines - row) < MAXY)
 		    for(count = 0; count <= (maxlines - row); count++)
-			wprintw(win->address, (printHex) ? "%08X ":"%08d ",
-			       (count + row) * BASE);
+			wprintw(win->address, (printHex) ? "%0*jX ":"%0*jd ",
+			       MIN_ADDR_LENGTH, (intmax_t)((count + row) * BASE));
 		else
 		    for(count = 0; count <= MAXY && count <= maxlines ; count++)
-			wprintw(win->address, (printHex) ? "%08X ":"%08d ",
-			       (count + row) * BASE);
+			wprintw(win->address, (printHex) ? "%0*jX ":"%0*jd ",
+			       MIN_ADDR_LENGTH, (intmax_t)((count + row) * BASE));
 
 							/* update menu button */
 		slk_set(6, (printHex) ? "Hex Addr":"Dec Addr", 1);
@@ -551,8 +591,12 @@ int wacceptch(WINS *win, long len, char *fpINfilename, char *fpOUTfilename)
 		    wrefresh(win->hex_outline);
 		    break;
 		}
-
-		gotoLoc = strtol(gotoLocStr, NULL, 16); /* convert str 2 hex  */
+                
+                /* convert str to number */
+                if (sscanf(gotoLocStr, printHex ? "%jX" : "%jd", &tmp_max) != 1)
+                    tmp_max = 0;
+                    
+                gotoLoc = (off_t)tmp_max;
 		/*wscanw(win->hex_outline, (printHex) ? "%X":"%d",&gotoLoc);  */
 		noecho();				/* disable echoing    */
 
@@ -616,6 +660,7 @@ int wacceptch(WINS *win, long len, char *fpINfilename, char *fpOUTfilename)
 
 	case CTRL_AND('?'):
 	case CTRL_AND('h'):
+	case CTRL_AND('p'):
 	case KEY_F(1):					/* if F1, ^?, ^h...   */
 		getyx(Winds, row, col);			/* current location   */
 
@@ -747,8 +792,8 @@ int wacceptch(WINS *win, long len, char *fpINfilename, char *fpOUTfilename)
 	LastLoc = cursorLoc(currentLine, col, editHex, BASE);
 	lastLine = currentLine;
 							/* print cur location */
-	mvwprintw(win->cur_address, 0, 0, (printHex) ? "%08X":"%08d",
-	   	  cursorLoc(currentLine, col, editHex,BASE));
+	mvwprintw(win->cur_address, 0, 0, (printHex) ? "%0*jX":"%0*jd",
+	   	  MIN_ADDR_LENGTH, (intmax_t)cursorLoc(currentLine, col, editHex,BASE));
 	
 	wnoutrefresh(win->cur_address);			/* refresh outline    */
 	
@@ -758,9 +803,10 @@ int wacceptch(WINS *win, long len, char *fpINfilename, char *fpOUTfilename)
 	doupdate();					/* update visual      */
     }
 
-    /* if user chose to save on exit, value will == 2 */
-    if (save == 2) savefile(win, fpINfilename, fpOUTfilename);
-
+    free(temp);
+    while (stack != NULL)
+	popStack(&stack);
+    
     return 0;						/* return             */
 }
 
@@ -787,15 +833,22 @@ char *inputLine(WINDOW *win, int line, int col)
     int x;
     unsigned long int c;
     char *ch;
+    int allocated = 81;
 
     noecho();
 
-    ch = (char *)malloc(81);				/* allocate space     */
+    ch = (char *)malloc(allocated);				/* allocate space     */
 
     wmove(win, line, col);
 
     for (x = 0; (c = wgetch(win)) != 10; x++) 
     {
+	if (x > 0 && x >= allocated)
+	{
+		ch = (char*)realloc(ch, x + 1);
+		allocated = x + 1;
+	}
+	
         wclrtoeol(win);					/* clear line         */
         if (c == '\b' || c == 127) 			/* get backspace      */
 	{
