@@ -27,9 +27,6 @@ void init_menu(WINS *windows)
     int x;
     WINDOW *win;
 
-    for (x = 1; x < 24; x++)				/* blocks all signals */
-	signal(x, SIG_IGN);				/* ignores the sigs   */
-
     /*signal(SIGCHLD,  SIG_DFL);                                              */
     signal(SIGSEGV,  catchSegfault);			/* catch segfault sig */
     /* the following is still under development, please report any bugs found */
@@ -41,12 +38,12 @@ void init_menu(WINS *windows)
 	    			     ascii_outline_width);
     windows->scrollbar = newwin(LINES, 1, 0, hex_outline_width);
 
-    windows->hex = newwin(LINES - 2, hex_win_width, 1, 10);
+    windows->hex = newwin(LINES - 2, hex_win_width, 1, MIN_ADDR_LENGTH + 2);
     windows->ascii = newwin(LINES - 2, ascii_win_width, 1, 
 	                    hex_outline_width + 2);
-    windows->address = newwin(LINES - 2, 9, 1, 1);
+    windows->address = newwin(LINES - 2, MIN_ADDR_LENGTH + 1, 1, 1);
 
-    windows->cur_address = newwin(1, 8, 0, 1);
+    windows->cur_address = newwin(1, MIN_ADDR_LENGTH, 0, 1);
 
     waddch(windows->scrollbar, ACS_UARROW);
     wattron(windows->scrollbar, A_REVERSE);
@@ -73,6 +70,34 @@ void init_menu(WINS *windows)
 
 }
 
+/******************************************************\
+ * Description: Deallocates the windows               *
+ *		that the hex editor uses.             *
+\******************************************************/
+void free_windows(WINS *windows)
+{
+      delwin(windows->cur_address);
+      windows->cur_address = NULL;
+      
+      delwin(windows->address);
+      windows->address = NULL;
+      
+      delwin(windows->ascii);
+      windows->ascii = NULL;
+      
+      delwin(windows->hex);
+      windows->hex = NULL;
+      
+      delwin(windows->scrollbar);
+      windows->scrollbar = NULL;
+      
+      delwin(windows->ascii_outline);
+      windows->ascii_outline = NULL;
+      
+      delwin(windows->hex_outline);
+      windows->hex_outline = NULL;
+}
+
 /******************************************************\
  * Description:	exit the program printing out an error*
  *		from the errno value.	 	      *
@@ -134,21 +159,25 @@ void init_fkeys()
  *		terminal and prompts for the user to  *
  *		change the screen.		      *
 \******************************************************/
-void checkScreenSize(int sig)
+RETSIGTYPE checkScreenSize(int sig)
 {   
     int count;
+    
+    /* Avoid unused variable warning */
+    UNUSED(sig);
 
     clearScreen(windows);
     endwin();
     init_screen();                                      /* init visuals       */
+    init_colors();
 
     slk_clear();                                        /* init menu bar      */
     slk_restore();                                      /* restore bottom menu*/
     slk_noutrefresh();
     doupdate();
 							/* recacl these values*/
-    BASE                =   (COLS - 14) / 4;            /*base for the number */
-    hex_outline_width   =   (BASE * 3) + 11;
+    BASE                =   (COLS - 6 - MIN_ADDR_LENGTH) / 4;            /*base for the number */
+    hex_outline_width   =   (BASE * 3) + 3 + MIN_ADDR_LENGTH;
     MAXY                =   LINES - 3;
     hex_win_width       =   BASE * 3;
     ascii_outline_width =   BASE + 2;
@@ -184,15 +213,9 @@ void checkScreenSize(int sig)
 	    for (count = 0; count <= MAXY && count <= maxLines(maxLoc(fpIN)); 
 		 count++)
 		outline(fpIN, count);
-	    /*
-	    mvwprintw(windows->cur_address, 0, 0, (printHex) ? "%08X":"%08d",
-		      LastLoc);
-	    */
-	    mvwprintw(windows->cur_address, 0, 0, "%s", "00000000");
+
+	    mvwprintw(windows->cur_address, 0, 0, "%0*d", MIN_ADDR_LENGTH, 0);
 	    wmove(windows->hex,0,0);
-	    /*currentLine = gotoLine(fpIN, 0, LastLoc, maxlines,
-				    (editHex) ? windows->hex : windows->ascii);
-				       */
 	}
 
 	refreshall(windows);
@@ -241,6 +264,9 @@ void scrollbar(WINS *windows,  int cl, long maxLines)
 {
     float x, percent;
 
+    /* Avoid unused variable warning */
+    UNUSED(maxLines);
+    
     /* cl really should be a long, it wasn't changed because cl is used
      * in other functions as an int.  Eventually everything should be using
      * long rather than int */
@@ -252,7 +278,7 @@ void scrollbar(WINS *windows,  int cl, long maxLines)
 
     x = (int)(percent * (float)(LINES));
     x = (x < 1) ? 1 : x;
-    x = (x >= (LINES - 1)) ?  x = LINES - 2 : x;
+    x = (x >= (LINES - 1)) ? LINES - 2 : x;
 
     wattron(windows->scrollbar, A_REVERSE);		/* set attribs on bar */
     wattron(windows->scrollbar, A_REVERSE);		/* set attribs on bar */
@@ -399,37 +425,6 @@ void clearScreen(WINS *win)
     doupdate();
 }
 
-/******************************************************\
- * Description:	Checks if the exit key has been       *
- *		pressed.  If so, it checks if the     *
- *		file has been saved since the last    *
- *		modification.  If it hasn't it prompts*
- *		the user asking if they would like to *
- *		save.				      *
- * Returns:     2 == save, 1 == no save, 0 == cancel  *
-\******************************************************/
-int quitProgram(int notChanged, short int ch)
-{   
-    short int str;
-							/* if exit key...     */
-    if ((ch == KEY_F(8)) || (ch == CTRL_AND('q')) || (ch == CTRL_AND('x')))
-    {
-        if (!notChanged)				/* if changes made    */
-        {
-							/* prompt for exit    */
-            str = questionWin("Do you want to save changes? (y/n)");
-
-            if (str == 'Y' || str == 'y')		/* if yes, save       */
-                return 2;
-            else if ((str != 'N') && (str != 'n'))	/* don't quit, cancel */
-                return 0;
-        }
-
-        return 1;					/* quit, don't save   */
-    }
-    else 
-        return 0;					/* don't quit         */
-}
 
 /******************************************************\
  * Description:	Creates a "window popup" where given  *
